# OpenReview Python Client

Unlike other openreview client this doesn't require any webdriver install and 

```
import openreview
submission = openreview.extract_forum('NeurIPS.cc/2019/Reproducibility_Challenge/-/NeurIPS_Submission')
print(len(submission))
```


